/**
 * @file
 *
 * Weather JavaScript helpers implementation.
 */

(function($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.weatherPlacesHelper = {
    attach: function (context) {

      $(context).on("ajaxComplete", function( event, xhr, settings ) {
        drupalSettings.google.autocomplete.places = xhr.responseJSON;

        let $place_id = '';
        $(context).find('a[id^="ui-id"]').on('click', async function () {
          let $item = $(this).text();
          drupalSettings.google.autocomplete.places.forEach(function ($element) {
            if ($element['label'] === $item) {
              $place_id = $element['place_id'];
            }
          })

          let suggestion = await findPlace($place_id).then(json => {return json});
          let $coordinates = suggestion.results[0].geometry.location;
          $('#edit-displayed-name').val($item);
          $('#edit-lat').val($coordinates['lat']);
          $('#edit-lon').val($coordinates['lng']);
          let geoname_data = await findGeonameId($coordinates['lat'], $coordinates['lng']).then(json => {return json});
          $('#edit-geoid').val('geonames_' + geoname_data.geonames[0].geonameId);
        })
      });

      /**
       * Initiate places search mechanism.
       *
       * @param place_id
       *   The given place ID.
       *
       * @returns {Promise<any>}
       *   Returns response content.
       */
      async function findPlace(place_id) {
        let response = await fetch('https://maps.googleapis.com/maps/api/geocode/json?key=' + drupalSettings.google.auth + '&place_id=' + place_id);
        return await response.json();
      }

      /**
       *
       * @param lat
       *   The latitude coordinate value.
       * @param lon
       *   The longitude coordinate value.
       *
       * @returns {Promise<any>}
       *   Returns response content.
       */
      async function findGeonameId(lat, lon) {
        let response = await fetch('http://api.geonames.org/findNearbyPlaceNameJSON?formatted=true&lat=' + lat + '&lng=' + lon + '&username=' + drupalSettings.google.geoname_uid);
        return await response.json();
      }

    }
  };
}(jQuery, Drupal, drupalSettings));
