<?php

namespace Drupal\weather\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Http\RequestStack;
use Symfony\Component\HttpFoundation\JsonResponse;
use GuzzleHttp\Client;

/**
 * Provides an interface to get Google places autocomplete API suggestions.
 */
class WeatherPlacesAutocompleteController extends ControllerBase {

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   *
   */
  protected $request;

  /**
   * @var \Symfony\Contracts\HttpClient\HttpClientInterface
   */
  protected $httpClient;

  /**
   * The controller constructor.
   *
   * @param \Drupal\Core\Http\RequestStack $request_stack
   *   The request stack service.
   * @param \GuzzleHttp\Client $http_client
   *   The http client service.
   */
  public function __construct(RequestStack $request_stack, Client $http_client) {
    $this->request = $request_stack->getMainRequest();
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack'),
      $container->get('http_client')
    );
  }

  /**
   * Provides autocomplete field suggestions for location widget.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   */
  public function autocomplete(): JsonResponse {
    $weather_config = $this->config('weather.settings');
    $google_api_key = $weather_config->get('gmaps_api_key');

    $to_render = [];
    $request = $this->httpClient->get('https://maps.googleapis.com/maps/api/place/autocomplete/json?key=' . $google_api_key . '&input=' . urlencode($this->request->get('q')));
    $content = $request->getBody()->getContents();
    if (!empty($content)) {
      foreach (json_decode($content, TRUE)['predictions'] as $item) {
        $to_render[] = [
          'value' => $item['description'],
          'label' => $item['description'],
          'place_id' => $item['place_id'],
        ];
      }
    }
    return new JsonResponse($to_render);
  }

}
